@@ -173,6 +173,10 @@ public:
     bool    eraze;
     int     tt;
     int     nb_tt;*/
+    double    nof_cfls;
+    double    nbcfls;
+    bool     isConflict;
+    vec<Lit> interpretation;
     int     prior_limit;
     vec<Lit> prior_lits;
     double max_act;
@@ -189,14 +193,16 @@ public:
     bool eraze;
     int b1;
     int b2;
-    double n1;
-    double n1_old;
     double n2;
+    double n1_old;
+    double n1;
     int m1;
     int nb_res;
     double somme;
     int nb_unit;
     Lit    conflict_lit;
+    int                 nbExp;
+    vec<Lit>            gClause;
     vec<Lit>            Graph_Lit;
     vec<char>           seen2;
     vec<char>           seen3;
@@ -208,6 +214,7 @@ public:
 
     // Main internal methods:
     //
+    void     restrartStrategy(Cooperation* coop);
     void     searchMostActivVar(Cooperation* C);
     void     Clauses_shared_Control(Cooperation * coop);
     void     Clauses_shared_Control_Q(Cooperation * coop);
@@ -405,6 +412,9 @@ public:
         double    B; // throughput                          
         double ** average_e;
         double * nb_compute_e;
+	
+	bool*          getFromPrecedentCore;
+	bool*          permitWrite;
 
 
 
@@ -422,7 +432,8 @@ public:
 	void importUnits(Solver*);
 
 	void print();
-
+	void sendCurrentInt(Solver* s, int id);
+	void exportClauseTo(Solver* s, vec<Lit>& learnt);
 	~Cooperation(){//TODO
 	}
 };
